<?php

/**
 * @file
 * Configuration for ipstack module.
 */

/**
 * Ipstack settings form.
 */
function ipstack_settings_form($form, &$form_state) {
  $form['ipstack_api_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Ipstack API key'),
    '#required' => TRUE,
    '#default_value' => variable_get('ipstack_api_key', ''),
    '#description' => t("Get Access Key by register at
      <a href='@url' rel='nofollow' target='_new'>ipstack.com</a>.",
      array('@url' => 'https://ipstack.com')
    ),
  );

  $form['ipstack_use_https'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use HTTPS'),
    '#default_value' => variable_get('ipstack_use_https', FALSE),
    '#description' => t('Connect to the API via HTTPS. For premium plans only.'),
  );

  $form['ipstack_use_cache'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use cache'),
    '#default_value' => variable_get('ipstack_use_cache', FALSE),
    '#description' => t('Use cache data for IP instead IPstack API request.'),
  );

  $form['#submit'][] = 'ipstack_settings_form_submit';
  return system_settings_form($form);
}

/**
 * Ipstack settings form submit.
 */
function ipstack_settings_form_submit($form, &$form_state) {
  // Clear cache because clearing check 'use cache' settings.
  $cached = _ipstack_clear_cache();
  if ($cached) {
    drupal_set_message(t('Ipstack cache was cleared.'));
  }
}

/**
 * Ipstack test form.
 */
function ipstack_test_form($form, &$form_state) {
  // Clear cache because options may be changed.
  $cached = _ipstack_clear_cache();
  if ($cached) {
    drupal_set_message(t('Ipstack cache was cleared.'));
  }

  $ip = variable_get('ipstack_ip', ip_address());

  $form = array();
  $form['ip'] = array(
    '#type' => 'textfield',
    '#title' => t('IP address'),
    '#required' => TRUE,
    '#default_value' => $ip,
    '#description' => t("IP address for test retrieving
      <a href='@url' rel='nofollow' target='_new'>ipstack.com</a> data.",
      array('@url' => 'https://ipstack.com')
    ),
  );

  $fields = array(
    'main' => t('(main) returns main API objects from "ip" to "longitude"'),
    'country_code' => t('(country_code) returns only the "country_code" object'),
    'location' => t('(location) returns the entire "location" object with sub-objects'),
    'location.capital ' => t('(location.capital) returns only the "capital" object inside "location"'),
  );
  $form['fields'] = array(
    '#type' => 'select',
    '#title' => t('Response Fields'),
    '#required' => FALSE,
    '#multiple' => TRUE,
    '#options' => $fields,
    '#default_value' => variable_get('ipstack_fields'),
    '#description' => t("Specify Response Fields. Look details at
      <a href='@url' rel='nofollow' target='_new'>documentation</a>.",
      array('@url' => 'https://ipstack.com/documentation#fields')
    ),
  );
  $form['hostname'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Hostname Lookup'),
    '#required' => FALSE,
    '#default_value' => variable_get('ipstack_hostname'),
    '#description' => t("Include the hostname object. Look details at
      <a href='@url' rel='nofollow' target='_new'>documentation</a>.",
      array('@url' => 'https://ipstack.com/documentation#hostname')
    ),
  );
  $form['security'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable the Security module'),
    '#required' => FALSE,
    '#default_value' => variable_get('ipstack_security'),
    '#description' => t("Assess risks and threats originating. Look details at
      <a href='@url' rel='nofollow' target='_new'>documentation</a>.",
      array('@url' => 'https://ipstack.com/documentation#security')
    ),
  );
  $languages = array(
    'en' => t('English/US'),
    'de' => t('German'),
    'es' => t('Spanish'),
    'fr ' => t('French'),
    'ja' => t('Japanese'),
    'pt-br' => t('Portugues (Brazil)'),
    'ru' => t('Russian'),
    'zh' => t('Chinese'),
  );
  $form['language'] = array(
    '#type' => 'select',
    '#title' => t('Specify Response Language'),
    '#required' => FALSE,
    '#multiple' => FALSE,
    '#options' => array(t('Default (English/Us)')) + $languages,
    '#default_value' => variable_get('ipstack_language', 0),
    '#description' => t("Delivering its result set in different languages. Look details at
      <a href='@url' rel='nofollow' target='_new'>documentation</a>.",
      array('@url' => 'https://ipstack.com/documentation#language')
    ),
  );
  $formats = array(
    'json' => 'JSON',
    'xml' => 'XML',
  );
  $form['output'] = array(
    '#type' => 'select',
    '#title' => t('Output format'),
    '#required' => FALSE,
    '#multiple' => FALSE,
    '#options' => array(t('Default (JSON)')) + $formats,
    '#default_value' => variable_get('ipstack_output', 0),
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Test'),
  );

  return $form;
}

/**
 * Form submission for ipstack_test_form().
 */
function ipstack_test_form_submit($form, &$form_state) {
  $ip = $form_state['values']['ip'];
  variable_set('ipstack_ip', $ip);

  // Build request options.
  $options = array();
  $options_keys = array('fields', 'hostname', 'security', 'language', 'output');
  foreach ($options_keys as $key) {
    $value = $form_state['values'][$key];

    // Save the last value.
    variable_set("ipstack_$key", $value);

    if (!empty($value)) {
      if (is_array($value)) {
        $value = implode(',', $value);
      }
      $options[$key] = $value;
    }
  }

  // Data output.
  _ipstack_output($ip, $options);
}

/**
 * Clear Ipstack cache.
 */
function _ipstack_clear_cache() {
  $use_cache = variable_get('ipstack_use_cache', FALSE);
  if ($use_cache) {
    // Clear cache.
    cache_clear_all('ipstack:ip_', 'cache', TRUE);
    return TRUE;
  }

  return FALSE;
}
